/*  30th June 2006. UIAV Venice mobile services workshop. 
    By David Mellis & Vinay Venkatraman
    
    This code lets you control a slideshow of images.  Pressing the right,
    down, or center (fire) keys advances to the next slide; pressing up or
    left goes to the previous slide.  
    
    Images should be placed in the "data" directory of this sketch.
    
    Tested on a Nokia 6630 Phone only 
*/

import processing.phone.*;     // import phone library for fullScreen() function

Phone p;

// The current image (slide) being displayed; the first image is number 0.
int cur_image = 0;

// The file name of the background image.
String bgfile = "blue.png";

// The actual background image.
PImage bgimage;

// An array of the names of the image files for the slides, in order.
// Each file can appear multiple times.
String files[] = { "menu-map.png", "menu-game.png", "menu-talk.png", "menu-game.png",
  "menu-map.png", "map1.png", "map2.png", "map3.png", "map4.png", "map-zoomed.png" };

// An array of the actual slide images.
PImage images[];

void setup()
{
  // Load the background image.
  bgimage = loadImage(bgfile);
  
  // Create an array to hold the slide images (files.length is the
  // length of the files array - that is, the number of slides).
  images = new PImage[files.length];
  
  // Load each of the slide images.
  for (int i = 0; i < files.length; i = i + 1)
    images[i] = loadImage(files[i]);

  p = new Phone(this);
  p.fullscreen();              // Go full screen   
}

// Just draw whatever the current image happens to be; it will be updated
// in the keyPressed() function.
void draw()
{
  // Draw the background image.
  image(bgimage, 0, 0);
  
  // Draw the current slide image.
  image(images[cur_image], 0, 0);
}

// This function is called (once) when a key is pressed.  We use it to set
// the number of the current image, which gets shown in draw().
void keyPressed()
{
  if (keyCode == RIGHT || keyCode == DOWN || keyCode == FIRE)
    cur_image = cur_image + 1;
  else if (keyCode == LEFT || keyCode == UP)
    cur_image = cur_image - 1;

  // Keep the current image within the range of images available (which goes
  // from zero to one less than the number of images available).
  cur_image = constrain(cur_image, 0, images.length - 1);
}
